@@ -246,7 +246,8 @@ class TestLoaderProxy:
                 tests.extend([(MissingTest, {'name': reference})
                               for reference in unhandled_references])
             else:
-                if force == 'on':
+                # This is a workaround to avoid changing the method signature
+                if force is True or force == 'on':
                     LOG_UI.error(LoaderUnhandledReferenceError(unhandled_references,
                                                                self._initialized_plugins))
                 else:
@@ -676,8 +677,8 @@ class FileLoader(SimpleFileLoader):
                 test_path = test_path[:-3]
             test_module_name = os.path.relpath(test_path)
             test_module_name = test_module_name.replace(os.path.sep, ".")
-            candidates = [("%s.%s.%s" % (test_module_name, klass, method), tags)
-                          for (method, tags) in methods]
+            candidates = [("%s.%s.%s" % (test_module_name, klass, method),
+                           tags) for (method, tags, _) in methods]
             if subtests_filter:
                 result += [_ for _ in candidates if subtests_filter.search(_)]
             else:
@@ -711,7 +712,7 @@ class FileLoader(SimpleFileLoader):
                 test_factories = []
                 for test_class, info in avocado_tests.items():
                     if isinstance(test_class, str):
-                        for test_method, tgs in info:
+                        for test_method, tags, _ in info:
                             name = test_name + \
                                 ':%s.%s' % (test_class, test_method)
                             if (subtests_filter and
@@ -720,7 +721,7 @@ class FileLoader(SimpleFileLoader):
                             tst = (test_class, {'name': name,
                                                 'modulePath': test_path,
                                                 'methodName': test_method,
-                                                'tags': tgs})
+                                                'tags': tags})
                             test_factories.append(tst)
                 return test_factories
             # Python unittests
