@@ -80,7 +80,7 @@ def cpu_has_flags(flags):
     Check if a list of flags are available on current CPU info
 
     :param flags: A `list` of cpu flags that must exists on the current CPU.
-    :type flags: `list`
+    :type flags: `list` of str
     :returns: `bool` True if all the flags were found or False if not
     :rtype: `list`
     """
@@ -90,7 +90,7 @@ def cpu_has_flags(flags):
         flags = [flags]
 
     for flag in flags:
-        if not _list_matches(cpu_info, '.*%s.*' % flag):
+        if not any([flag.encode() in line for line in cpu_info]):
             return False
     return True
 
@@ -100,8 +100,8 @@ def get_version():
     Get cpu version
 
     :returns: string cpu version of given machine
-    Eg.:- 'i5-5300U' for Intel and 'POWER9' for IBM machines
-    in case of unknown/unsupported machines, return an empty string
+              Eg.:- 'i5-5300U' for Intel and 'POWER9' for IBM machines in
+              case of unknown/unsupported machines, return an empty string.
     """
     version_pattern = {'x86_64': rb'\s([\S,\d]+)\sCPU',
                        'i386': rb'\s([\S,\d]+)\sCPU',
@@ -252,10 +252,11 @@ def online(cpu):
     """
     Online given CPU
     """
-    with open("/sys/devices/system/cpu/cpu%s/online" % cpu, "wb") as fd:
-        fd.write(b'1')
-    if _get_status(cpu):
-        return 0
+    if _get_status(cpu) is False:
+        with open("/sys/devices/system/cpu/cpu%s/online" % cpu, "wb") as fd:
+            fd.write(b'1')
+        if _get_status(cpu):
+            return 0
     return 1
 
 
@@ -263,10 +264,11 @@ def offline(cpu):
     """
     Offline given CPU
     """
-    with open("/sys/devices/system/cpu/cpu%s/online" % cpu, "wb") as fd:
-        fd.write(b'0')
     if _get_status(cpu):
-        return 1
+        with open("/sys/devices/system/cpu/cpu%s/online" % cpu, "wb") as fd:
+            fd.write(b'0')
+        if _get_status(cpu):
+            return 1
     return 0
 
 
