@@ -32,6 +32,7 @@ from avocado.utils import script
 from avocado.utils import path as utils_path
 
 from .. import AVOCADO, BASEDIR, python_module_available, temp_dir_prefix
+from .. import skipOnLevelsInferiorThan
 
 
 UNSUPPORTED_STATUS_TEST_CONTENTS = '''
@@ -219,7 +220,7 @@ class RunnerOperationTest(unittest.TestCase):
 
     def test_runner_ignore_missing_references_one_missing(self):
         cmd_line = ('%s run --sysinfo=off --job-results-dir %s '
-                    'passtest.py badtest.py --ignore-missing-references on'
+                    'passtest.py badtest.py --ignore-missing-references'
                     % (AVOCADO, self.tmpdir.name))
         result = process.run(cmd_line, ignore_status=True)
         self.assertIn(b"Unable to resolve reference(s) 'badtest.py'", result.stderr)
@@ -230,7 +231,7 @@ class RunnerOperationTest(unittest.TestCase):
 
     def test_runner_ignore_missing_references_all_missing(self):
         cmd_line = ('%s run --sysinfo=off --job-results-dir %s '
-                    'badtest.py badtest2.py --ignore-missing-references on'
+                    'badtest.py badtest2.py --ignore-missing-references'
                     % (AVOCADO, self.tmpdir.name))
         result = process.run(cmd_line, ignore_status=True)
         self.assertIn(b"Unable to resolve reference(s) 'badtest.py', 'badtest2.py'",
@@ -272,11 +273,12 @@ class RunnerOperationTest(unittest.TestCase):
             self.assertIn("Runner error occurred: Test reports unsupported",
                           results["tests"][0]["fail_reason"])
 
-    @unittest.skipIf(int(os.environ.get("AVOCADO_CHECK_LEVEL", 0)) < 1,
-                     "Skipping test that take a long time to run, are "
-                     "resource intensive or time sensitve")
+    @skipOnLevelsInferiorThan(1)
     def test_hanged_test_with_status(self):
-        """ Check that avocado handles hanged tests properly """
+        """Check that avocado handles hanged tests properly.
+
+        :avocado: tags=parallel:1
+        """
         with script.TemporaryScript("report_status_and_hang.py",
                                     REPORTS_STATUS_AND_HANG,
                                     "hanged_test_with_status") as tst:
@@ -426,10 +428,11 @@ class RunnerOperationTest(unittest.TestCase):
         # Ensure no test aborted error messages show up
         self.assertNotIn(b"TestAbortError: Test aborted unexpectedly", output)
 
-    @unittest.skipIf(int(os.environ.get("AVOCADO_CHECK_LEVEL", 0)) < 2,
-                     "Skipping test that take a long time to run, are "
-                     "resource intensive or time sensitve")
+    @skipOnLevelsInferiorThan(2)
     def test_runner_abort(self):
+        """
+        :avocado: tags=parallel:1
+        """
         cmd_line = ('%s run --sysinfo=off --job-results-dir %s '
                     '--xunit - abort.py' % (AVOCADO, self.tmpdir.name))
         result = process.run(cmd_line, ignore_status=True)
@@ -498,12 +501,12 @@ class RunnerOperationTest(unittest.TestCase):
         int(r['job_id'], 16)  # it's an hex number
         self.assertEqual(len(r['job_id']), 40)
 
-    @unittest.skipIf(int(os.environ.get("AVOCADO_CHECK_LEVEL", 0)) < 2,
-                     "Skipping test that take a long time to run, are "
-                     "resource intensive or time sensitve")
+    @skipOnLevelsInferiorThan(2)
     def test_early_latest_result(self):
         """
         Tests that the `latest` link to the latest job results is created early
+
+        :avocado: tags=parallel:1
         """
         cmd_line = ('%s run --sysinfo=off --job-results-dir %s '
                     'examples/tests/passtest.py' % (AVOCADO, self.tmpdir.name))
@@ -552,10 +555,11 @@ class RunnerOperationTest(unittest.TestCase):
                       result.stdout_text)
 
     @unittest.skipIf(not READ_BINARY, "read binary not available.")
-    @unittest.skipIf(int(os.environ.get("AVOCADO_CHECK_LEVEL", 0)) < 1,
-                     "Skipping test that take a long time to run, are "
-                     "resource intensive or time sensitve")
+    @skipOnLevelsInferiorThan(1)
     def test_read(self):
+        """
+        :avocado: tags=parallel:1
+        """
         cmd = "%s run --sysinfo=off --job-results-dir %%s %%s" % AVOCADO
         cmd %= (self.tmpdir.name, READ_BINARY)
         result = process.run(cmd, timeout=10, ignore_status=True)
@@ -724,9 +728,7 @@ class RunnerSimpleTest(unittest.TestCase):
                          "Avocado did not return rc %d:\n%s" %
                          (expected_rc, result))
 
-    @unittest.skipIf(int(os.environ.get("AVOCADO_CHECK_LEVEL", 0)) < 2,
-                     "Skipping test that take a long time to run, are "
-                     "resource intensive or time sensitve")
+    @skipOnLevelsInferiorThan(2)
     def test_runner_onehundred_fail_timing(self):
         """
         We can be pretty sure that a failtest should return immediately. Let's
@@ -734,6 +736,8 @@ class RunnerSimpleTest(unittest.TestCase):
 
         Notice: on a current machine this takes about 0.12s, so 30 seconds is
         considered to be pretty safe here.
+
+        :avocado: tags=parallel:1
         """
         one_hundred = 'failtest.py ' * 100
         cmd_line = ('%s run --job-results-dir %s --sysinfo=off %s'
@@ -746,13 +750,13 @@ class RunnerSimpleTest(unittest.TestCase):
         self.assertEqual(result.exit_status, expected_rc,
                          "Avocado did not return rc %d:\n%s" % (expected_rc, result))
 
-    @unittest.skipIf(int(os.environ.get("AVOCADO_CHECK_LEVEL", 0)) < 2,
-                     "Skipping test that take a long time to run, are "
-                     "resource intensive or time sensitve")
+    @skipOnLevelsInferiorThan(2)
     def test_runner_sleep_fail_sleep_timing(self):
         """
         Sleeptest is supposed to take 1 second, let's make a sandwich of
         100 failtests and check the test runner timing.
+
+        :avocado: tags=parallel:1
         """
         sleep_fail_sleep = ('sleeptest.py ' + 'failtest.py ' * 100 +
                             'sleeptest.py')
@@ -845,11 +849,12 @@ class RunnerSimpleTest(unittest.TestCase):
                          (expected_rc, result))
 
     @unittest.skipIf(not SLEEP_BINARY, 'sleep binary not available')
-    @unittest.skipIf(int(os.environ.get("AVOCADO_CHECK_LEVEL", 0)) < 2,
-                     "Skipping test that take a long time to run, are "
-                     "resource intensive or time sensitve")
+    @skipOnLevelsInferiorThan(2)
     @unittest.skipUnless(AEXPECT_CAPABLE, 'aexpect package not available')
     def test_kill_stopped_sleep(self):
+        """
+        :avocado: tags=parallel:1
+        """
         proc = aexpect.Expect("%s run 60 --job-results-dir %s "
                               "--external-runner %s --sysinfo=off "
                               "--job-timeout 3"
@@ -1261,7 +1266,7 @@ class PluginsXunitTest(AbsPluginsTest, unittest.TestCase):
         super(PluginsXunitTest, self).setUp()
 
     def run_and_check(self, testname, e_rc, e_ntests, e_nerrors,
-                      e_nnotfound, e_nfailures, e_nskip):  # pylint: disable=W0613
+                      e_nfailures, e_nskip):
         cmd_line = ('%s run --job-results-dir %s --sysinfo=off'
                     ' --xunit - %s' % (AVOCADO, self.tmpdir.name, testname))
         result = process.run(cmd_line, ignore_status=True)
@@ -1309,19 +1314,19 @@ class PluginsXunitTest(AbsPluginsTest, unittest.TestCase):
 
     def test_xunit_plugin_passtest(self):
         self.run_and_check('passtest.py', exit_codes.AVOCADO_ALL_OK,
-                           1, 0, 0, 0, 0)
+                           1, 0, 0, 0)
 
     def test_xunit_plugin_failtest(self):
         self.run_and_check('failtest.py', exit_codes.AVOCADO_TESTS_FAIL,
-                           1, 0, 0, 1, 0)
+                           1, 0, 1, 0)
 
     def test_xunit_plugin_skiponsetuptest(self):
         self.run_and_check('cancelonsetup.py', exit_codes.AVOCADO_ALL_OK,
-                           1, 0, 0, 0, 1)
+                           1, 0, 0, 1)
 
     def test_xunit_plugin_errortest(self):
         self.run_and_check('errortest.py', exit_codes.AVOCADO_TESTS_FAIL,
-                           1, 1, 0, 0, 0)
+                           1, 1, 0, 0)
 
     def tearDown(self):
         self.tmpdir.cleanup()
