@@ -91,9 +91,7 @@ class Runnable(unittest.TestCase):
     def test_runner_from_runnable_error(self):
         runnable = nrunner.Runnable('unsupported_kind', '')
         try:
-            nrunner.runner_from_runnable(
-                runnable,
-                nrunner.RunnerApp.RUNNABLE_KINDS_CAPABLE)
+            runnable.pick_runner_class()
         except ValueError as e:
             self.assertEqual(str(e), 'Unsupported kind of runnable: unsupported_kind')
 
@@ -188,34 +186,31 @@ class Runner(unittest.TestCase):
 
     def test_runner_noop(self):
         runnable = nrunner.Runnable('noop', None)
-        runner = nrunner.runner_from_runnable(
-            runnable,
-            nrunner.RunnerApp.RUNNABLE_KINDS_CAPABLE)
+        runner_klass = runnable.pick_runner_class()
+        runner = runner_klass(runnable)
         results = [status for status in runner.run()]
         last_result = results[-1]
         self.assertEqual(last_result['status'], 'finished')
-        self.assertIn('time_end', last_result)
+        self.assertIn('time', last_result)
 
     def test_runner_exec(self):
         runnable = nrunner.Runnable('exec', sys.executable,
                                     '-c', 'import time; time.sleep(0.01)')
-        runner = nrunner.runner_from_runnable(
-            runnable,
-            nrunner.RunnerApp.RUNNABLE_KINDS_CAPABLE)
+        runner_klass = runnable.pick_runner_class()
+        runner = runner_klass(runnable)
         results = [status for status in runner.run()]
         last_result = results[-1]
         self.assertEqual(last_result['status'], 'finished')
         self.assertEqual(last_result['returncode'], 0)
         self.assertEqual(last_result['stdout'], b'')
         self.assertEqual(last_result['stderr'], b'')
-        self.assertIn('time_end', last_result)
+        self.assertIn('time', last_result)
 
     def test_runner_exec_test_ok(self):
         runnable = nrunner.Runnable('exec-test', sys.executable,
                                     '-c', 'import time; time.sleep(0.01)')
-        runner = nrunner.runner_from_runnable(
-            runnable,
-            nrunner.RunnerApp.RUNNABLE_KINDS_CAPABLE)
+        runner_klass = runnable.pick_runner_class()
+        runner = runner_klass(runnable)
         results = [status for status in runner.run()]
         last_result = results[-1]
         self.assertEqual(last_result['status'], 'finished')
@@ -223,13 +218,12 @@ class Runner(unittest.TestCase):
         self.assertEqual(last_result['returncode'], 0)
         self.assertEqual(last_result['stdout'], b'')
         self.assertEqual(last_result['stderr'], b'')
-        self.assertIn('time_end', last_result)
+        self.assertIn('time', last_result)
 
     def test_runner_exec_test_fail(self):
         runnable = nrunner.Runnable('exec-test', '/bin/false')
-        runner = nrunner.runner_from_runnable(
-            runnable,
-            nrunner.RunnerApp.RUNNABLE_KINDS_CAPABLE)
+        runner_klass = runnable.pick_runner_class()
+        runner = runner_klass(runnable)
         results = [status for status in runner.run()]
         last_result = results[-1]
         self.assertEqual(last_result['status'], 'finished')
@@ -237,13 +231,12 @@ class Runner(unittest.TestCase):
         self.assertEqual(last_result['returncode'], 1)
         self.assertEqual(last_result['stdout'], b'')
         self.assertEqual(last_result['stderr'], b'')
-        self.assertIn('time_end', last_result)
+        self.assertIn('time', last_result)
 
     def test_runner_python_unittest_ok(self):
         runnable = nrunner.Runnable('python-unittest', 'unittest.TestCase')
-        runner = nrunner.runner_from_runnable(
-            runnable,
-            nrunner.RunnerApp.RUNNABLE_KINDS_CAPABLE)
+        runner_klass = runnable.pick_runner_class()
+        runner = runner_klass(runnable)
         results = [status for status in runner.run()]
         output1 = ('----------------------------------------------------------'
                    '------------\nRan 0 tests in ')
@@ -256,9 +249,8 @@ class Runner(unittest.TestCase):
 
     def test_runner_python_unittest_fail(self):
         runnable = nrunner.Runnable('python-unittest', 'unittest.TestCase.fail')
-        runner = nrunner.runner_from_runnable(
-            runnable,
-            nrunner.RunnerApp.RUNNABLE_KINDS_CAPABLE)
+        runner_klass = runnable.pick_runner_class()
+        runner = runner_klass(runnable)
         results = [status for status in runner.run()]
         output1 = ('============================================================='
                    '=========\nFAIL: fail (unittest.case.TestCase)'
@@ -274,9 +266,8 @@ class Runner(unittest.TestCase):
         runnable = nrunner.Runnable(
             'python-unittest',
             'selftests.unit.test_test.TestClassTestUnit.DummyTest.skip')
-        runner = nrunner.runner_from_runnable(
-            runnable,
-            nrunner.RunnerApp.RUNNABLE_KINDS_CAPABLE)
+        runner_klass = runnable.pick_runner_class()
+        runner = runner_klass(runnable)
         results = [status for status in runner.run()]
         output1 = ('----------------------------------------------------------'
                    '------------\nRan 1 test in ')
@@ -289,9 +280,8 @@ class Runner(unittest.TestCase):
 
     def test_runner_python_unittest_error(self):
         runnable = nrunner.Runnable('python-unittest', 'error')
-        runner = nrunner.runner_from_runnable(
-            runnable,
-            nrunner.RunnerApp.RUNNABLE_KINDS_CAPABLE)
+        runner_klass = runnable.pick_runner_class()
+        runner = runner_klass(runnable)
         results = [status for status in runner.run()]
         output1 = ('============================================================='
                    '=========\nERROR: error')
@@ -304,9 +294,8 @@ class Runner(unittest.TestCase):
 
     def test_runner_python_unittest_empty_uri_error(self):
         runnable = nrunner.Runnable('python-unittest', '')
-        runner = nrunner.runner_from_runnable(
-            runnable,
-            nrunner.RunnerApp.RUNNABLE_KINDS_CAPABLE)
+        runner_klass = runnable.pick_runner_class()
+        runner = runner_klass(runnable)
         results = [status for status in runner.run()]
         output = 'uri is required but was not given'
         result = results[-1]
@@ -441,41 +430,39 @@ echo 'ok 2 - description 2'"""
 class RunnerCommandSelection(unittest.TestCase):
 
     def setUp(self):
-        runnable = nrunner.Runnable('mykind',
-                                    'test_runner_command_selection')
-        self.task = nrunner.Task('1-test_runner_command_selection', runnable)
+        self.runnable = nrunner.Runnable('mykind',
+                                         'test_runner_command_selection')
 
     def test_is_task_kind_supported(self):
         cmd = ['sh', '-c',
                'test $0 = capabilities && '
                'echo -n {\\"runnables\\": [\\"mykind\\"]}']
-        self.assertTrue(self.task.is_kind_supported_by_runner_command(cmd))
+        self.assertTrue(self.runnable.is_kind_supported_by_runner_command(cmd))
 
     def test_is_task_kind_supported_other_kind(self):
         cmd = ['sh', '-c',
                'test $0 = capabilities && '
                'echo -n {\\"runnables\\": [\\"otherkind\\"]}']
-        self.assertFalse(self.task.is_kind_supported_by_runner_command(cmd))
+        self.assertFalse(self.runnable.is_kind_supported_by_runner_command(cmd))
 
     def test_is_task_kind_supported_no_output(self):
         cmd = ['sh', '-c', 'echo -n ""']
-        self.assertFalse(self.task.is_kind_supported_by_runner_command(cmd))
+        self.assertFalse(self.runnable.is_kind_supported_by_runner_command(cmd))
 
 
 class PickRunner(unittest.TestCase):
 
     def setUp(self):
-        runnable = nrunner.Runnable('lets-image-a-kind',
-                                    'test_pick_runner_command')
-        self.task = nrunner.Task('1-test_pick_runner_command', runnable)
+        self.runnable = nrunner.Runnable('lets-image-a-kind',
+                                         'test_pick_runner_command')
 
     def test_pick_runner_command(self):
         runner = ['avocado-runner-lets-image-a-kind']
         known = {'lets-image-a-kind': runner}
-        self.assertEqual(self.task.pick_runner_command(known), runner)
+        self.assertEqual(self.runnable.pick_runner_command(known), runner)
 
     def test_pick_runner_command_empty(self):
-        self.assertFalse(self.task.pick_runner_command({}))
+        self.assertFalse(self.runnable.pick_runner_command({}))
 
 
 if __name__ == '__main__':
