@@ -10,7 +10,7 @@ from avocado.utils import script
 from avocado.utils import process
 from avocado.utils import path
 
-from .. import setup_avocado_loggers
+from .. import setup_avocado_loggers, skipOnLevelsInferiorThan
 
 
 setup_avocado_loggers()
@@ -52,7 +52,7 @@ class TestSubProcess(unittest.TestCase):
     @unittest.mock.patch('avocado.utils.process.SubProcess.get_pid')
     @unittest.mock.patch('avocado.utils.process.get_children_pids')
     @unittest.mock.patch('avocado.utils.process.run')
-    def test_send_signal_sudo_enabled(self, run, get_children, get_pid, sudo, init):  # pylint: disable=W0613
+    def test_send_signal_sudo_enabled(self, run, get_children, get_pid, sudo, _):
         signal = 1
         pid = 122
         child_pid = 123
@@ -73,8 +73,8 @@ class TestSubProcess(unittest.TestCase):
     @unittest.mock.patch('avocado.utils.process.SubProcess.get_pid')
     @unittest.mock.patch('avocado.utils.process.get_children_pids')
     @unittest.mock.patch('avocado.utils.process.run')
-    def test_send_signal_sudo_enabled_with_exception(
-            self, run, get_children, get_pid, sudo, init):  # pylint: disable=W0613
+    def test_send_signal_sudo_enabled_with_exception(self, run, get_children,
+                                                     get_pid, sudo, _):
         signal = 1
         pid = 122
         child_pid = 123
@@ -94,7 +94,7 @@ class TestSubProcess(unittest.TestCase):
     @unittest.mock.patch('avocado.utils.process.SubProcess._init_subprocess')
     @unittest.mock.patch('avocado.utils.process.SubProcess.get_pid')
     @unittest.mock.patch('avocado.utils.process.get_owner_id')
-    def test_get_user_id(self, get_owner, get_pid, init):  # pylint: disable=W0613
+    def test_get_user_id(self, get_owner, get_pid, _):
         user_id = 1
         process_id = 123
         get_pid.return_value = process_id
@@ -108,7 +108,7 @@ class TestSubProcess(unittest.TestCase):
     @unittest.mock.patch('avocado.utils.process.SubProcess._init_subprocess')
     @unittest.mock.patch('avocado.utils.process.SubProcess.get_pid')
     @unittest.mock.patch('avocado.utils.process.get_owner_id')
-    def test_is_sudo_enabled_false(self, get_owner, get_pid, init):  # pylint: disable=W0613
+    def test_is_sudo_enabled_false(self, get_owner, get_pid, _):
         user_id = 1
         process_id = 123
         get_pid.return_value = process_id
@@ -122,7 +122,7 @@ class TestSubProcess(unittest.TestCase):
     @unittest.mock.patch('avocado.utils.process.SubProcess._init_subprocess')
     @unittest.mock.patch('avocado.utils.process.SubProcess.get_pid')
     @unittest.mock.patch('avocado.utils.process.get_owner_id')
-    def test_is_sudo_enabled_true(self, get_owner, get_pid, init):  # pylint: disable=W0613
+    def test_is_sudo_enabled_true(self, get_owner, get_pid, _):
         user_id = 0
         process_id = 123
         get_pid.return_value = process_id
@@ -290,10 +290,11 @@ class TestProcessRun(unittest.TestCase):
         self.assertEqual(result.stdout, encoded_text)
         self.assertEqual(result.stdout_text, text)
 
-    @unittest.skipIf(int(os.environ.get("AVOCADO_CHECK_LEVEL", 1)) < 2,
-                     "Skipping test that take a long time to run, are "
-                     "resource intensive or time sensitve")
+    @skipOnLevelsInferiorThan(2)
     def test_run_with_timeout_ugly_cmd(self):
+        """
+        :avocado: tags=parallel:1
+        """
         with script.TemporaryScript("refuse_to_die", REFUSE_TO_DIE) as exe:
             cmd = "%s '%s'" % (sys.executable, exe.path)
             # Wait 1s to set the traps
@@ -305,10 +306,11 @@ class TestProcessRun(unittest.TestCase):
                                 "reporting failure but should be killed.\n%s"
                                 % res)
 
-    @unittest.skipIf(int(os.environ.get("AVOCADO_CHECK_LEVEL", 0)) < 2,
-                     "Skipping test that take a long time to run, are "
-                     "resource intensive or time sensitve")
+    @skipOnLevelsInferiorThan(2)
     def test_run_with_negative_timeout_ugly_cmd(self):
+        """
+        :avocado: tags=parallel:1
+        """
         with script.TemporaryScript("refuse_to_die", REFUSE_TO_DIE) as exe:
             cmd = "%s '%s'" % (sys.executable, exe.path)
             # Wait 1s to set the traps
